@@ -6,11 +6,11 @@ from trytond.pyson import Eval
 
 from .stock import DATE_STATE
 
-__all__ = ['Template']
-__metaclass__ = PoolMeta
+__all__ = ['Template', 'Product']
 
 
 class Template:
+    __metaclass__ = PoolMeta
     __name__ = 'product.template'
 
     shelf_life_state = fields.Selection(
@@ -37,3 +37,8 @@ class Template:
     @staticmethod
     def default_expiration_state():
         return 'none'
+
+
+class Product:
+    __metaclass__ = PoolMeta
+    __name__ = 'product.product'
